@@ -331,18 +331,10 @@ struct NDhcp4CConnection {
 
         NDhcp4Outgoing *request;        /* current request */
 
+        uint64_t ns_drain_timeout;      /* timeout for closing packet socket */
         uint32_t client_ip;             /* client IP address, or 0 */
         uint32_t server_ip;             /* server IP address, or 0 */
         uint16_t mtu;                   /* client mtu, or 0 */
-
-        /*
-         * When we get DHCP packets from the kernel, we need a buffer to read
-         * the data into. Since UDP packets can be up to 2^16 bytes in size, we
-         * avoid placing it on the stack and instead read into this scratch
-         * buffer. It is purely meant as stack replacement, no data is returned
-         * through this buffer.
-         */
-        uint8_t scratch_buffer[UINT16_MAX];
 };
 
 #define N_DHCP4_C_CONNECTION_NULL(_x) {                                         \
@@ -387,6 +379,7 @@ struct NDhcp4ClientProbe {
         uint64_t ns_deferred;                   /* timeout for deferred action */
         uint64_t ns_reinit;
         uint64_t ns_nak_restart_delay;          /* restart delay after a nak */
+        uint64_t ns_decline_restart_delay;      /* restart delay after a decline */
         NDhcp4ClientLease *current_lease;       /* current lease */
 
         NDhcp4CConnection connection;           /* client connection wrapper */
